@@ -25,7 +25,7 @@ use Data::Dumper;
 use Term::ProgressBar;
 use Term::ANSIColor;
 
-our $VERSION = '0.6.0'; # VERSION
+our $VERSION = '0.7.0'; # VERSION
 
 has config => ( is => 'ro' );
 has logger => ( is => 'ro' );
@@ -35,6 +35,12 @@ sub ua {
   my $ua = LWP::UserAgent->new;
   $ua->env_proxy;
 
+  if ( $self->config->{DownloadTimeout} ) {
+    $self->logger->debug(
+      "Setting download timeout to: " . $self->config->{DownloadTimeout} );
+    $ua->timeout( $self->config->{DownloadTimeout} );
+  }
+
   if ( exists $option{ssl_opts} ) {
     for my $key ( keys %{ $option{ssl_opts} } ) {
       $ua->ssl_opts( $key, $option{ssl_opts}->{$key} );
@@ -60,17 +66,27 @@ sub parse_cli_option {
   }
 
   if ( exists $option{mirror} && exists $option{repo} ) {
-    $self->print_info("Going to mirror " . $option{repo} . ". This may take a while.");
+    $self->print_info(
+      "Going to mirror " . $option{repo} . ". This may take a while." );
     print "\n";
 
+    my $update_files = 1;
+
+   # so it is possible to only update metadata. (for example: for proxy support)
+    if ( exists $option{"no-update-files"} && $option{"no-update-files"} ) {
+      $update_files = 0;
+    }
+
     $self->mirror(
       repo            => $option{repo},
-      update_metadata => $option{"update-metadata"},
-      update_files    => $option{"update-files"},
+      update_metadata => ( $option{"update-metadata"} || 0 ),
+      update_files    => $update_files,
+      force           => ( $option{"force-download"} || 0 ),
     );
 
-    print "\n"; print "\n";
-    $self->print_info("Finished downloading of files for " . $option{repo});
+    print "\n";
+    print "\n";
+    $self->print_info( "Finished downloading of files for " . $option{repo} );
     print "\n";
   }
 
@@ -140,7 +156,10 @@ sub server {
   $ENV{'REPO_NAME'}   = $option{repo};
   $ENV{'MOJO_MAX_MESSAGE_SIZE'} = 1024 * 1024 * 1024 * 1024; # set max_message_size astronomically high / TODO: make it configurable
   my $server_type = $self->config->{Repository}->{ $option{repo} }->{type};
-  if ( $server_type eq "Apt" ) {
+  if ( $server_type eq "Apt"
+    || $server_type eq "OpenSuSE"
+    || $server_type eq "Plain" )
+  {
     $server_type = "Yum";
   }
   Mojolicious::Commands->start_app("Rex::Repositorio::Server::$server_type");
@@ -339,6 +358,10 @@ sub mirror {
         type     => BOOLEAN,
         optional => 1,
       },
+      force => {
+        type     => BOOLEAN,
+        optional => 1,
+      },
     }
   );
 
@@ -363,7 +386,8 @@ sub mirror {
 
     $repo_o->mirror(
       update_metadata => $option{update_metadata},
-      update_files    => $option{update_files}
+      update_files    => $option{update_files},
+      force           => $option{force},
     );
   }
 }
@@ -407,6 +431,9 @@ sub tag {
 
       $self->logger->debug(
         "Linking (hard): $dir/$entry -> $tag_dir/$rel_entry");
+      if ( -f File::Spec->catfile( $tag_dir, $rel_entry ) ) {
+        unlink File::Spec->catfile( $tag_dir, $rel_entry );
+      }
       link "$dir/$entry", "$tag_dir/$rel_entry";
     }
     closedir $dh;
@@ -510,6 +537,8 @@ sub _help {
     "--repo=reponame     the name of the repository to use",
     "--update-metadata   update the metadata of a repository",
     "--update-files      download files even if they are already downloaded",
+    "--force-download    force the download of already downloaded files",
+    "--no-update-files   do not download packages",
     "--init              initialize an empty repository",
     "--add-file=file     add a file to a repository (needs --repo)",
     "--remove-file=file  remove a file from a repository (needs --repo)",
