@@ -26,7 +26,7 @@ use Term::ReadKey;
 use JSON::XS;
 use List::MoreUtils 'firstidx';
 
-our $VERSION = '0.6.0'; # VERSION
+our $VERSION = '0.7.0'; # VERSION
 
 has app  => ( is => 'ro' );
 has repo => ( is => 'ro' );
@@ -84,7 +84,17 @@ sub download {
   if ( !$resp->is_success ) {
     $self->app->logger->error("Can't download $url.");
     $self->app->logger->error( "Status: " . $resp->status_line );
-    confess "Error downloading $url.";
+    my $retry_count = 1;
+    while ( !$resp->is_success
+      && $retry_count <= ( $self->app->config->{DownloadRetryCount} // 3 ) )
+    {
+      $self->app->logger->error("Retry downloading of url: $url");
+      $retry_count += 1;
+      $resp = $self->ua->get($url);
+    }
+    if ( !$resp->is_success ) {
+      confess "Error downloading $url.";
+    }
   }
 
   return $resp->content;
@@ -118,20 +128,25 @@ sub download_package {
         type     => CODEREF,
         optional => 1,
       },
+      update_file => {
+        type     => BOOLEAN,
+        optional => 1,
+      },
       force => {
         type     => BOOLEAN,
         optional => 1,
-      }
+      },
     }
   );
 
   my $package_file =
     $self->app->config->{RepositoryRoot} . "/head/" . $option{dest};
   $self->_download_binary_file(
-    dest  => $package_file,
-    url   => $option{url},
-    cb    => $option{cb},
-    force => $option{force},
+    dest        => $package_file,
+    url         => $option{url},
+    cb          => $option{cb},
+    force       => $option{force},
+    update_file => $option{update_file},
   );
 }
 
@@ -183,8 +198,13 @@ sub _download_binary_file {
         optional => 1,
       },
       force => {
-        type => BOOLEAN
-      }
+        type     => BOOLEAN,
+        optional => 1,
+      },
+      update_file => {
+        type     => BOOLEAN,
+        optional => 1,
+      },
     }
   );
 
@@ -192,6 +212,25 @@ sub _download_binary_file {
 
   mkpath( dirname( $option{dest} ) ) if ( !-d dirname $option{dest} );
 
+  if ( exists $option{cb}
+    && ref $option{cb} eq "CODE"
+    && $option{update_file}
+    && -f $option{dest} )
+  {
+    eval {
+      $option{cb}->( $option{dest} );
+      1;
+    } or do {
+
+      # if callback is failing, we need to download the file once again.
+      # so just set force to true
+      $self->app->logger->debug(
+        "Setting option force -> 1: update_file is enabled and callback failed."
+      );
+      $option{force} = 1;
+    };
+  }
+
   if ( -f $option{dest} && !$option{force} ) {
     $self->app->logger->debug("Skipping $option{url}. File already exists.");
     return;
@@ -223,7 +262,8 @@ sub _download_binary_file {
     confess "Error downloading $option{url}.";
   }
 
-  $option{cb}->( $option{dest} ) if ( exists $option{cb} && $option{cb} );
+  $option{cb}->( $option{dest} )
+    if ( exists $option{cb} && ref $option{cb} eq "CODE" );
 }
 
 sub add_file_to_repo {
