@@ -17,7 +17,7 @@ use File::Path;
 use IO::All;
 use JSON::XS;
 
-our $VERSION = '0.6.0'; # VERSION
+our $VERSION = '0.7.0'; # VERSION
 
 extends "Rex::Repositorio::Repository::Base";
 
@@ -33,9 +33,9 @@ sub mirror {
     length => 3,
   );
 
-  my ($packages_ref, $repomd_ref);
-  ($packages_ref, $repomd_ref) = $self->_get_repomd_xml($self->repo->{url});
-  my @packages = @{ $packages_ref };
+  my ( $packages_ref, $repomd_ref );
+  ( $packages_ref, $repomd_ref ) = $self->_get_repomd_xml( $self->repo->{url} );
+  my @packages = @{$packages_ref};
 
   try {
     $self->download_metadata(
@@ -59,7 +59,7 @@ sub mirror {
     $self->app->logger->error($_);
   };
 
-  $self->_download_packages(\%option, @packages);
+  $self->_download_packages( \%option, @packages );
 
   print "\n";
   print "\n";
@@ -131,9 +131,13 @@ sub mirror {
 }
 
 sub _download_packages {
-  my ($self, $_option, @packages) = @_;
+  my ( $self, $_option, @packages ) = @_;
 
-  my %option = %{ $_option };
+  if ( !$_option->{update_files} && !$_option->{force} ) {
+    return;
+  }
+
+  my %option = %{$_option};
 
   my $i = 0;
   print "\n";
@@ -162,17 +166,17 @@ sub _download_packages {
           $package->{checksum}->{data}
         );
       },
-      force => $option{update_files}
+      update_file => $option{update_files},
+      force       => $option{force},
     );
   }
 }
 
 sub _get_repomd_xml {
-  my ($self, $url) = @_;
+  my ( $self, $url ) = @_;
 
   my $repomd_ref =
-    $self->decode_xml(
-    $self->download( "$url/repodata/repomd.xml" ) );
+    $self->decode_xml( $self->download("$url/repodata/repomd.xml") );
 
   my ($primary_file) =
     grep { $_->{type} eq "primary" } @{ $repomd_ref->{data} };
@@ -201,7 +205,7 @@ sub _get_repomd_xml {
       };
   }
 
-  return (\@packages, $repomd_ref);
+  return ( \@packages, $repomd_ref );
 }
 
 sub init {
